{% load static sekizai_tags %}
<div data-django-ads-zone="{{ zone|safe }}" data-django-ads-extra-classes="{{ extra_classes|safe }}"></div>
{% addtoblock "js" %}<script defer src='{% static 'ads/ads.js' %}'></script>{% endaddtoblock %}
