# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-02-08 10:15
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ads', '0003_auto_20170207_1034'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ad',
            name='image',
        ),
    ]
