# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-26 10:45
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ads', '0004_remove_ad_image'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ad',
            name='created_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='Created By'),
        ),
        migrations.AlterField(
            model_name='adimage',
            name='device',
            field=models.CharField(choices=[('xs', 'Smartphones'), ('sm', 'Tablets'), ('md', 'Small Desktops'), ('lg', 'Large Desktops')], max_length=2, verbose_name='Device'),
        ),
        migrations.AlterField(
            model_name='adimage',
            name='image',
            field=models.ImageField(max_length=255, upload_to='', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='advertiser',
            name='created_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='Created By'),
        ),
        migrations.AlterField(
            model_name='category',
            name='created_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='Created By'),
        ),
    ]
